#
#-------------------------------------------------------------------------------
# @(#) motorola-bss/tech_pack_support/Motorola_BSS/GSR8/UserConfig.pm motorola-bss_r3.0.0.latest:cset.002547:2:2@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Motorola BSS CSV Parser
# 
# Copyright (c) 2007 Vallent Software Systems. All rights reserved.
#
package UserConfig;


@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

#use diagnostics;
use strict;
use Exporter ();


#-------------------------------------------------------------------------------


my @rules = (


{
RULE_TYPE => 'FILE_SPLIT',
RULE_DESC => "Split file based on date, start time and end time",
INPUT_FILE_DESCRIPTION => ['.+'],
COUNTERS_USED_TO_SPLIT_FILE => {
	'start' => '(.+)',
	'day' => '(.+)',
	'end' => '(.+)',
	},
SPLIT_COUNTERS_ORDER => [ qw(day start end) ],
PRODUCE_PIF => "True",
PRODUCE_LIF => 0,
#OUTPUT_BLOCK_NAME => 'FS',
REDUNDANT_DATA_COUNTERS => [],
},

{
RULE_TYPE => 'PERLIZE',
RULE_DESC => 'Remove all counters except required cntrs',
INPUT_FILE_DESCRIPTION => '^carrier_stats[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$', 
DATA_COUNTERS_OP => sub
{
	my $c_ref = shift;
 	my($key_str)="";	
	foreach $key_str (keys(%$c_ref))
	{
		if ( ($key_str ne 'day' )
		   && ($key_str ne 'start' )
		   && ($key_str ne 'end' )
		   && ($key_str ne 'cellid' )
		   && ($key_str ne 'btsid' )
		   && ($key_str ne 'end' )
		   && ($key_str ne 'nodeid' )
		   && ($key_str ne 'DURATION' )
		   && ($key_str ne 'START_DATE' )
		   && ($key_str ne 'START_TIME' )
		   && ($key_str ne 'END_TIME' )
		   && ($key_str ne 'PERIOD' )
		   && ($key_str ne 'chan_req_ms_fail0' )
		   && ($key_str ne 'chan_req_ms_fail1' )
		   && ($key_str ne 'chan_req_ms_fail2' )
		   && ($key_str ne 'chan_req_ms_fail3' )
		   && ($key_str ne 'chan_req_ms_fail4' )
		   && ($key_str ne 'chan_req_ms_fail5' )
		   && ($key_str ne 'chan_req_ms_fail6' )
		   && ($key_str ne 'chan_req_ms_fail7' )
		   && ($key_str ne 'rf_losses_tch0' )
		   && ($key_str ne 'rf_losses_tch1' )
		   && ($key_str ne 'rf_losses_tch2' )
		   && ($key_str ne 'rf_losses_tch3' )
		   && ($key_str ne 'rf_losses_tch4' )
		   && ($key_str ne 'rf_losses_tch5' )
		   && ($key_str ne 'rf_losses_tch6' )
		   && ($key_str ne 'rf_losses_tch7' ) )
		   {
			delete($$c_ref{$key_str});
		   }
	}
# all okay
return 0;
},
FILENAME_SUFFIX => 'RSZ',
PRODUCE_LIF => 0,
PRODUCE_PIF => 'True',
},

{
'RULE_TYPE'              => 'ACCUMULATE',
'RULE_DESC'              => 'Aggregate carrier stats 1',
'PRODUCE_PIF'            => 'True',
'PRODUCE_LIF'            => 0,
'OUTPUT_BLOCK_NAME'      => 'CARRIER_STATS_AGG',
'INPUT_FILE_DESCRIPTION' => '^carrier_stats[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS-#-RSZ.pif$', 
'COUNTERS_TO_SORT_ON'    => ['nodeid','btsid','cellid'],
'NON_ADDITIVE_COUNTERS'  => ['start','end','day','DURATION','START_DATE','START_TIME','PERIOD','END_TIME'],
'REDUNDANT_COUNTERS'     => [],
},
{
'RULE_TYPE' => 'JOIN',
'RULE_DESC' => 'Merging cell_stats, cell_stats2 and cgprs_stats',
'INPUT_FILE_DESCRIPTION' => [ 
'^cell_stats[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$',
'^cell_stats[0-9][\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$',
'^carrier_stats[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS-#-RSZ-#-CARRIER_STATS_AGG-#-A.pif$',],
#'^(.*)cgprs_stats.*-#-I.pif' ],
'PRODUCE_PIF' => 'True',
'PRODUCE_LIF' => 0,
'OUTPUT_BLOCK_NAME' => 'cell_stats',
'COUNTERS_TO_JOIN_ON' => ['nodeid', 'btsid', 'cellid'],
'OUTPUT_FILENAME_START' => 'all_cell',
'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ['FILENAME'],
},


{
RULE_TYPE => 'PERLIZE',
RULE_DESC => 'Unpacking cellid to LACID',
INPUT_FILE_DESCRIPTION => '^all_cell.*-#-J.pif',
DATA_COUNTERS_OP => sub
{
my $c_ref = shift;
# create a holding counter
my $tmp = $c_ref->{cellid};
$tmp = substr($tmp,0) ;
$c_ref->{lacid} = substr($tmp,1,3) ;
# all okay
return 0;
},
FILENAME_SUFFIX => 'PL',
PRODUCE_LIF => 0,
PRODUCE_PIF => 'True',
OUTPUT_BLOCK_NAME => 'cell_stats',
},

# Split RNC object counters into respective blocks
{
    RULE_TYPE                   => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                   => 'Split CELL object counters into respective blocks',
    INPUT_FILE_DESCRIPTION      => 'all_cell-#-.+-#-J-#-PL.pif',
    SPLIT_CNAMES => {

'ewRLCblkULACK' => [ '^ul_rlc_ack_new_bks$','^ulrlcaknewbks_cs1$','^ulrlcaknewbks_cs2$','^ulrlcaknewbks_cs3$','^ulrlcaknewbks_cs4$','^ulrlcaknewbks_mcs1$','^ulrlcaknewbks_mcs2$','^ulrlcaknewbks_mcs3$','^ulrlcaknewbks_mcs4$','^ulrlcaknewbks_mcs5$','^ulrlcaknewbks_mcs6$','^ulrlcaknewbks_mcs7$','^ulrlcaknewbks_mcs8$','^ulrlcaknewbks_mcs9$' ],
'MS_clas_1_t_29' => [ '^ms_class_1_10_req$','^ms_class_11_20_req$','^ms_class_21_29_req$','^ms_class_1_req$','^ms_class_2_req$','^ms_class_3_req$','^ms_class_4_req$','^ms_class_5_req$','^ms_class_6_req$','^ms_class_7_req$','^ms_class_8_req$','^ms_class_9_req$','^ms_class_10_req$','^ms_class_11_req$','^ms_class_12_req$','^ms_class_13_req$','^ms_class_14_req$','^ms_class_15_req$','^ms_class_16_req$','^ms_class_17_req$','^ms_class_18_req$','^ms_class_19_req$','^ms_class_20_req$','^ms_class_21_req$','^ms_class_22_req$','^ms_class_23_req$','^ms_class_24_req$','^ms_class_25_req$','^ms_class_26_req$','^ms_class_27_req$','^ms_class_28_req$','^ms_class_29_req$' ],
'Dur_UL_DL_TBFs' => [ '^ul_tbf_tm_8psk_2ts$','^ul_tbf_tm_gmsk_2ts$','^dl_tbf_time_1_ts$','^dl_tbf_time_3_ts$','^ul_tbf_tm_gmsk_1ts$','^dl_tbf_time_2_ts$','^dl_tbf_time_4_ts$','^ul_tbf_tm_8psk_1ts$' ],
'pkt_reqs' => [ '^pkt_sysinfo_req$','^pkt_sysreq_valid$','^pkt_sysreq_inval$','^pkt_sysreq_discard$','^pkt_sysreq_validp$' ],
'Intra_BSS_ho' => [ '^i_intra_bs_ho_los$','^i_intra_bs_eq_fa$','^i_intra_bs_ho_ret$','^i_intra_bs_ho_clr$','^i_intra_bs_ho_suc$','^o_intra_bs_ho_suc$','^o_intra_bs_ho_atm$','^o_intra_bs_ho_pri$','^o_intra_bs_ho_ret$','^o_intra_bs_ho_los$','^o_intra_bs_ho_req$','^o_intra_bs_eq_fa$','^o_intra_bs_ho_clr$','^sdch_i_intra_b_h_s$','^sdch_o_intra_b_h_s$' ],
'Imm_assig_proc' => [ '^imm_assgn_cse_tot$','^imm_assgn_cse_0$','^imm_assgn_cse_1$','^imm_assgn_cse_2$','^imm_assgn_cse_3$','^imm_assgn_cse_4$','^imm_assgn_cse_5$','^imm_assgn_cse_6$','^imm_assgn_cse_7$','^imm_assgn_cse_8$' ],
'EGPRS_codschch' => [ '^cs_change_bin_6$','^cs_change_bin_7$','^cs_change_bin_4$','^cs_change_bin_5$' ],
'UL_LLC_Data' => [ '^ul_llc_data_vol$','^ulllcvol_thp1_arp1$','^ulllcvol_thp1_arp2$','^ulllcvol_thp1_arp3$','^ulllcvol_thp2_arp1$','^ulllcvol_thp2_arp2$','^ulllcvol_thp2_arp3$','^ulllcvol_thp3_arp1$','^ulllcvol_thp3_arp2$','^ulllcvol_thp3_arp3$','^ulllcvol_bgrn_arp1$','^ulllcvol_bgrn_arp2$','^ulllcvol_bgrn_arp3$','^ulllcvol_eff_arp1$','^ulllcvol_eff_arp2$','^ulllcvol_eff_arp3$' ],
'blkULwith1TS' => [ '^ul_rf_bks_gmsk_1ts$','^ulrfbkgmsk1ts_cs1$','^ulrfbkgmsk1ts_cs2$','^ulrfbkgmsk1ts_cs3$','^ulrfbkgmsk1ts_cs4$','^ulrfbkgmsk1ts_mcs1$','^ulrfbkgmsk1ts_mcs2$','^ulrfbkgmsk1ts_mcs3$','^ulrfbkgmsk1ts_mcs4$' ],
'PFC_Dwng_Suc' => [ '^pfc_downgrade_succ$','^pfc_ds_thp2_1_arp1$','^pfc_ds_thp2_1_arp2$','^pfc_ds_thp2_1_arp3$','^pfc_ds_thp3_1_arp1$','^pfc_ds_thp3_1_arp2$','^pfc_ds_thp3_1_arp3$','^pfc_ds_thp3_2_arp1$','^pfc_ds_thp3_2_arp2$','^pfc_ds_thp3_2_arp3$' ],
'GPRS_trup_Ulcell' => [ '^ul_llc_frames$','^ul_llcframe_20$','^ul_llcframe_40$','^ul_llcframe_80$','^ul_llcframe_160$','^ul_llcframe_320$','^ul_llcframe_640$','^ul_llcframe_1280$','^ul_llcframe_over$' ],
'PFC_Upg' => [ '^pfc_upgrade$','^pfc_up_thp2_1_arp1$','^pfc_up_thp2_1_arp2$','^pfc_up_thp2_1_arp3$','^pfc_up_thp3_1_arp1$','^pfc_up_thp3_1_arp2$','^pfc_up_thp3_1_arp3$','^pfc_up_thp3_2_arp1$','^pfc_up_thp3_2_arp2$','^pfc_up_thp3_2_arp3$' ],
'C_M_AMR_FR' => [ '^amr_f_ul_c_m_u$','^amr_f_ul_c_m_u12$','^amr_f_ul_c_m_u10$','^amr_f_ul_c_m_u7$','^amr_f_ul_c_m_u6$','^amr_f_ul_c_m_u5$','^amr_f_dl_c_m_u$','^amr_f_dl_c_m_u12$','^amr_f_dl_c_m_u10$','^amr_f_dl_c_m_u7$','^amr_f_dl_c_m_u6$','^amr_f_dl_c_m_u5$' ],
'Inter_BSS_ho' => [ '^ho_req_msc_fail$','^ho_req_msc_ok$','^i_inter_bs_ho_suc$','^i_inter_bs_ms_ns$','^i_inter_bs_eq_fa$','^i_inter_bs_ho_clr$','^o_inter_bs_ho_suc$','^o_inter_bs_ho_atm$','^o_inter_bs_ho_ret$','^o_inter_bs_ho_los$','^o_inter_bs_eq_fa$','^o_inter_bs_ho_clr$','^o_inter_bs_rq_msc$','^o_inter_bs_ho_fail$','^sdch_i_inte_b_h_at$','^sdch_o_inter_b_h_s$' ],
'HO_acks_to_MSC' => [ '^ho_req_ak_msc_tot$','^ho_req_ak_msc_fr$','^ho_req_ak_msc_e_fr$','^ho_req_ak_msc_a_fr$','^ho_req_ak_msc_a_hr$','^ho_req_ak_msc_s_c$','^ho_req_ak_msc_otr$' ],
'blkDLexpNACK' => [ '^dl_rlc_nack_blks$','^dlrlcnackblks_cs1$','^dlrlcnackblks_cs2$','^dlrlcnackblks_cs3$','^dlrlcnackblks_cs4$','^dlrlcnackblks_mcs1$','^dlrlcnackblks_mcs2$','^dlrlcnackblks_mcs3$','^dlrlcnackblks_mcs4$','^dlrlcnackblks_mcs5$','^dlrlcnackblks_mcs6$','^dlrlcnackblks_mcs7$','^dlrlcnackblks_mcs8$','^dlrlcnackblks_mcs9$' ],
'bkUL2TSwo8PK' => [ '^ul_rf_bks_8psk_2ts$','^ulrfbk8psk2ts_cs1$','^ulrfbk8psk2ts_cs2$','^ulrfbk8psk2ts_cs3$','^ulrfbk8psk2ts_cs4$','^ulrfbk8psk2ts_mcs1$','^ulrfbk8psk2ts_mcs2$','^ulrfbk8psk2ts_mcs3$','^ulrfbk8psk2ts_mcs4$','^ulrfbk8psk2ts_mcs5$','^ulrfbk8psk2ts_mcs6$','^ulrfbk8psk2ts_mcs7$','^ulrfbk8psk2ts_mcs8$','^ulrfbk8psk2ts_mcs9$' ],
'C_M_AMR_ad_HR' => [ '^amr_hr_ul_adapt$','^amr_hr_ul_adapt1_2$','^amr_hr_ul_adapt2_3$','^amr_hr_ul_adapt3_4$','^amr_hr_ul_adapt2_1$','^amr_hr_ul_adapt3_2$','^amr_hr_ul_adapt4_3$','^amr_hr_dl_adapt$','^amr_hr_dl_adapt1_2$','^amr_hr_dl_adapt2_3$','^amr_hr_dl_adapt3_4$','^amr_hr_dl_adapt2_1$','^amr_hr_dl_adapt3_2$','^amr_hr_dl_adapt4_3$' ],
'Directed_retry' => [ '^cong_stand_ho_atm$','^cong_exist_ho_atm$' ],
'blkDLwith4TS' => [ '^dl_radio_blks_4_ts$','^dl_rf_bks_4ts_cs1$','^dl_rf_bks_4ts_cs2$','^dl_rf_bks_4ts_cs3$','^dl_rf_bks_4ts_cs4$','^dl_rf_bks_4ts_mcs1$','^dl_rf_bks_4ts_mcs2$','^dl_rf_bks_4ts_mcs3$','^dl_rf_bks_4ts_mcs4$','^dl_rf_bks_4ts_mcs5$','^dl_rf_bks_4ts_mcs6$','^dl_rf_bks_4ts_mcs7$','^dl_rf_bks_4ts_mcs8$','^dl_rf_bks_4ts_mcs9$' ],
'pktresreqblkus' => [ '^gprs_prr_blk_max$','^gprs_prr_blk_mean$','^gprs_prr_blk_min$' ],
'Dummy_LLCs' => [ '^dl_rlc_ddtr_blks$','^dlrlc_ddtrbks_cs1$','^dlrlc_ddtrbks_mcs1$' ],
'Call_clearing' => [ '^cipher_mode_fail$','^classmk_update_fa$','^clr_cmd_msc_sd$','^clr_cmd_msc_fr$','^clr_cmd_msc_hr$','^clr_cmd_msc_tot$','^clr_req_msc_sd$','^clr_req_msc_fr$','^clr_req_msc_hr$','^rf_losses_sd$','^rf_loss_tch_roll$','^clr_cmd_msc_vgcs$','^clr_req_msc_vgcs$' ],
'pkt_Response' => [ '^pkt_sysinfo_resp$','^pkt_sysresp_valid$','^pkt_sysresp_unenc$','^pkt_sysresp_outdat$' ],
'AMR_TCH' => [ '^tch_co_hr_amr$','^tch_cong_i_z_hr_a$','^bsy_tch_h_amr_mean$','^bsy_tch_h_amr_max$','^av_tch_hr_amr_max$','^av_tch_hr_amr_mn$','^alloc_tch_hr_amr$','^alloc_tch_fl_hr_a$','^rf_los_tch_hr_amr$' ],
'chnl_req' => [ '^ch_reqs_succ_p_c$','^ch_reqs_succ_p_p$','^ch_reqs_succ_b_c$','^ch_reqs_succ_b_p$','^ch_reqs_succ_p_r$','^ch_reqs_succ_cp_a$','^ch_reqs_succ_e_c$','^ch_reqs_succ_pkts$','^chan_reqs_rec_p_c$','^chan_reqs_rec_p_p$','^chan_reqs_rec_b_c$','^chan_reqs_rec_b_p$','^chan_reqs_rec_p_r$','^chan_reqs_rec_cp_a$','^chan_reqs_rec_e_c$','^dl_pdtch_seizure$','^air_dl_tbf_fl_dt$','^air_dl_tbf_fl_dr $','^air_dl_tbf_fl_t$','^air_dl_tbf_fl_et$','^ul_pdtch_seizure$','^air_ul_tbf_fl_dt$','^air_ul_tbf_fl_t$','^air_ul_tbf_fl_et$','^chanrqfailsdch_rol$' ],
'PFC_Dwng_fails' => [ '^pfc_downgrade_fail$','^pfc_df_thp2_1_arp1$','^pfc_df_thp2_1_arp2$','^pfc_df_thp2_1_arp3$','^pfc_df_thp3_1_arp1$','^pfc_df_thp3_1_arp2$','^pfc_df_thp3_1_arp3$','^pfc_df_thp3_2_arp1$','^pfc_df_thp3_2_arp2$','^pfc_df_thp3_2_arp3$' ],
'blkULretran' => [ '^ul_rlc_retx_blks$','^ulrlc_retxbks_cs1$','^ulrlc_retxbks_cs2$','^ulrlc_retxbks_cs3$','^ulrlc_retxbks_cs4$','^ulrlc_retxbks_mcs1$','^ulrlc_retxbks_mcs2$','^ulrlc_retxbks_mcs3$','^ulrlc_retxbks_mcs4$','^ulrlc_retxbks_mcs5$','^ulrlc_retxbks_mcs6$','^ulrlc_retxbks_mcs7$','^ulrlc_retxbks_mcs8$','^ulrlc_retxbks_mcs9$' ],
'blked_TBF' => [ '^blocked_dl_tbfs$','^insuff_rsl_bandwdt$','^insuff_resource$','^tbf_rej_qos_const$' ],
'FR_agnm_frmMSC' => [ '^ma_req_f_m_fer$','^ma_req_f_m_efr$','^ma_req_f_m_amr_f$','^ma_req_f_m_amr_hr$','^ma_req_f_m_sdch_c$','^ma_req_f_m_otr$' ],
'preemp_Service' => [ '^tch_preempt_rqd$','^tch_prmprqd_vgcs$','^tch_prmprqd_assign$','^tch_prmprqd_ho$','^tch_prmprqd_intho$','^tch_preempt_atmpt$','^tch_prmpatt_cs_cs$','^tch_prmpatt_vg_cs$','^tch_prmpatt_cs_vg$','^tch_prmpatt_vg_vg$','^tch_preempt_cap$','^prmpcap_vgcs$','^prmpcap_assign$','^prmpcap_ho$','^prmpcap_intho$','^tch_prmpt_failcand$','^tch_prmpt_failtime$','^q_preempt_atmpt$','^q_prmpatt_assign$','^q_prmpatt_ho$','^q_prmpatt_vgcs_vbs$','^tchpreemptnoqalloc$' ],
'Idle_UL_PDTCH' => [ '^idle_pdt_i_mean0$','^idle_pdt_i_max0$','^idle_pdt_i_mean1$','^idle_pdt_i_max1$','^idle_pdt_i_mean2$','^idle_pdt_i_max2$','^idle_pdt_i_mean3$','^idle_pdt_i_max3$','^idle_pdt_i_mean4$','^idle_pdt_i_max4$' ],
'EGPRS_chnl_res' => [ '^chanreqsuccesbccc$','^chanreqsucce1pccc$','^chanreqsuccepuaprr$','^chanreqsucceptr$','^chanreqsuccesbpccc$','^chnlrqrecegprssbpc$','^chnlrqrecegprs1pc$','^chnlrqrecegprs1ppc$','^chnlrqrecegprssbc$','^chnlrqrecegprscrpd$','^chanreqsucce1ccc$','^chnlrqrecegprspkrq$','^chanreqsuccepuapda$' ],
'Simult_TBF' => [ '^avgsimdltbfs_mean$','^avgsimdltbfs_max$','^avgsimultbfs_mean$','^avgsimultbfs_max$' ],
'Pag_req_msg' => [ '^acc_per_pch_ps_cs$','^acc_per_pch_cs$','^acc_per_pch_ps$' ],
'conn_estab' => [ '^access_per_agch$','^access_per_pch$','^access_per_rach$','^alloc_sdcch$','^alloc_sdcch_fail$','^chan_req_ms_fail0$','^chan_req_ms_fail1$','^chan_req_ms_fail2$','^chan_req_ms_fail3$','^chan_req_ms_fail4$','^chan_req_ms_fail5$','^chan_req_ms_fail6$','^chan_req_ms_fail7$','^alloc_tch$','^alloc_tch_fail$','^chan_req_caus_atm$','^cr_originat_call$','^cr_emerg_call$','^tch_q_removed$','^cr_call_reest$','^cr_location_upd$','^cr_page_response$','^cr_lmu_establish$','^chan_req_ms_blk$','^chan_req_fail_rol$','^conn_refused$','^conn_req_to_msc$','^inv_est_cause_rach$','^cm_serv_req_call$','^cm_serv_req_sms$','^cm_serv_req_supp$','^cm_serv_req_emerg$','^cm_reestablish$','^location_update$','^imsi_detach$','^page_response$','^ok_acc_proc$','^loc_flw_req_sms$','^loc_flw_req_nrm$','^cm_lcs_request$','^ok_acc_proc_suc_r$','^page_req_from_msc$','^clr_req_to_msc$','^cm_serv_req_vgcs$','^cm_serv_req_vbs$','^ms_req_vgcs_imm$','^ms_req_vgcs_imm2$','^ms_req_notif_resp$' ],
'C_M_AMR_adjust' => [ '^amr_inc_thr_adjust$','^amr_dec_thr_adjust$' ],
'GPRS_chl_unsrv' => [ '^ch_req_pcu_tot$','^ch_req_pcu_r_bw$','^ch_req_pcu_r_rtd$','^ch_req_pcu_r_ir$','^ch_req_pcu_p_rtd$','^ch_req_pcu_p_ir$','^ch_req_pcu_pr_rtd$','^ch_req_pcu_pr_ir$','^ch_req_pcu_pd_ir$' ],
'Calls_lt_onTCH' => [ '^rf_losses_tch0$','^rf_losses_tch1$','^rf_losses_tch2$','^rf_losses_tch3$','^rf_losses_tch4$','^rf_losses_tch5$','^rf_losses_tch6$','^rf_losses_tch7$' ],
'TBF_fails_pr_c' => [ '^air_dl_tbf_fl_tot$','^air_dl_tbf_fl_et$','^air_dl_tbf_fl_dt$','^air_dl_tbf_fl_dr$','^air_dl_tbf_fl_t$','^cong_rel_dl_scts$','^air_ul_tbf_fl_tot$','^air_ul_tbf_fl_et$','^air_ul_tbf_fl_dt$','^air_ul_tbf_fl_t$' ],
'blkDLwith3TS' => [ '^dl_radio_blks_3_ts$','^dl_rf_bks_3ts_cs1$','^dl_rf_bks_3ts_cs2$','^dl_rf_bks_3ts_cs3$','^dl_rf_bks_3ts_cs4$','^dl_rf_bks_3ts_mcs1$','^dl_rf_bks_3ts_mcs2$','^dl_rf_bks_3ts_mcs3$','^dl_rf_bks_3ts_mcs4$','^dl_rf_bks_3ts_mcs5$','^dl_rf_bks_3ts_mcs6$','^dl_rf_bks_3ts_mcs7$','^dl_rf_bks_3ts_mcs8$','^dl_rf_bks_3ts_mcs9$' ],
'Timer_Expiry' => [ '^pfc_timer_expiries$','^t5_expires$','^t6_expires$','^t8_expires$','^pft_expires$','^creat_t3168_expiry$','^finalt6_expiry$' ],
'PFC_Admission' => [ '^pfc_admsuccess$','^pfcadmsuc_thp1arp1$','^pfcadmsuc_thp1arp2$','^pfcadmsuc_thp1arp3$','^pfcadmsuc_thp2arp1$','^pfcadmsuc_thp2arp2$','^pfcadmsuc_thp2arp3$','^pfcadmsuc_thp3arp1$','^pfcadmsuc_thp3arp2$','^pfcadmsuc_thp3arp3$','^pfcadmsuc_bgrnarp1$','^pfcadmsuc_bgrnarp2$','^pfcadmsuc_bgrnarp3$','^pfcadmsuc_effarp1$','^pfcadmsuc_effarp2$','^pfcadmsuc_effarp3$' ],
'Emerg_call_acc' => [ '^emerg_access$','^emerg_tch_kill$','^emerg_rejected$','^emerg_term_sdcch$' ],
'Ext_range_cell' => [ '^err_intra_cell_ho$','^err_normal_extend$','^err_extend_normal$','^ers_intra_cell_ho$','^ers_normal_extend$','^tch_usg_ext_range$','^ers_extend_normal$' ],
'CellPDTCHav' => [ '^egprs_64k_nt_avail$','^egprs_64k_chns_swh$','^egprs_dl_asn_pccch$','^gprs_av_pdtch_max$','^gprs_av_pdtch_mn$','^egprs_av_pdtch_max$','^egprs_av_pdtch_mn$','^egpr_64chswtch_cs$','^egpr_64chswtch_vgc$','^gprs_32chswtch_cs$','^gprs_32chswtch_vgc$' ],
'PFC_Rej_Oth' => [ '^pfc_admrejectoth$','^pfcadmrej_sms$','^pfcadmrej_signal$','^pfcadmrej_unaware$' ],
'cell_stats' => [ '^avail_tch_max$','^avail_tch_mean$','^avail_sdcch_max$','^avail_sdcch_mean$','^busy_sdcch_max$','^busy_sdcch_mean$','^busy_tch_carrier_mean$','^busy_tch_carrier_max$','^busy_tch_mean$','^busy_tch_max$','^alloc_tch$','^calls_queued$','^flow_cntrl_barred$','^ma_complete_frm_ms$','^ma_complet_to_msc$','^mt_lcs_on_sdcch$','^paging_reqs_tot$','^paging_reqs_cs$','^paging_reqs_ps$','^pch_agch_q_max$','^pch_agch_q_mean$','^pch_page_q_discrd$','^pch_pgqdscrd_cs$','^pch_pgqdscrd_ps$','^sdcch_congestion$','^tch_congestion$','^tch_delay_mean$','^tch_delay_max$','^tch_q_length_max$','^tch_q_length_mean$','^tch_usage$','^sec_assign_atmpt$','^sec_assign_suc$','^sms_init_on_tch$','^sms_init_on_sdcch$','^sms_no_bcast_msg$','^cell_flush_reqs$','^channels_disabled$','^sms_init_sdcch_ho$','^avail_tchpgsm_mean$','^avail_tchpgsm_max$','^avail_tchegsm_mean$','^avail_tchegsm_max$','^avail_tchdcs_mean$','^avail_tchdcs_max$','^busy_tchpgsm_mean$','^busy_tchpgsm_max$','^busy_tchegsm_mean$','^busy_tchegsm_max$','^busy_tchdcs_mean$','^busy_tchdcs_max$','^calls_q_assign$','^calls_q_ho$','^calls_q_vg_vbs$','^bss_avail_max$','^bss_avail_mean$' ],
'TCH_inner_zone' => [ '^alloc_tch_inner_z$','^alloc_tch_fa_in_z$','^ho_req_in_zone$','^asgn_res_req_i_z$','^queue_vgcs$' ],
'blkULTSwo8PK' => [ '^ul_rf_bks_8psk_1ts$','^ulrfbk8psk1ts_cs1$','^ulrfbk8psk1ts_cs2$','^ulrfbk8psk1ts_cs3$','^ulrfbk8psk1ts_cs4$','^ulrfbk8psk1ts_mcs1$','^ulrfbk8psk1ts_mcs2$','^ulrfbk8psk1ts_mcs3$','^ulrfbk8psk1ts_mcs4$','^ulrfbk8psk1ts_mcs5$','^ulrfbk8psk1ts_mcs6$','^ulrfbk8psk1ts_mcs7$','^ulrfbk8psk1ts_mcs8$','^ulrfbk8psk1ts_mcs9$' ],
'PFC_Admi_Other' => [ '^pfc_admsuccessoth$','^pfcadmsuc_sms$','^pfcadmsuc_signal$','^pfcadmsuc_unaware$' ],
'GPRS_trup_Dlcell' => [ '^dl_llc_frames_gb$','^dl_llcframegb_20$','^dl_llcframegb_40$','^dl_llcframegb_80$','^dl_llcframegb_160$','^dl_llcframegb_320$','^dl_llcframegb_640$','^dl_llcframegb_1280$','^dl_llcframegb_over$','^dl_llc_frames_pcu$','^dl_llcframpcu_20$','^dl_llcframpcu_40$','^dl_llcframpcu_80$','^dl_llcframpcu_160$','^dl_llcframpcu_320$','^dl_llcframpcu_640$','^dl_llcframpcu_1280$','^dl_llcframpcu_over$' ],
'Nw_As_Chn' => [ '^num_cell_rsel_cell$','^resel_pccc_nacc$','^resel_pcco_nacc$','^resel_pcco_micro$','^resel_pcco_congest$','^resel_pcco_rf_nc2$','^pccn_request_ms$','^resel_success_$' ],
'Concent_cell' => [ '^tch_cong_iner_zon$','^tch_usage_inner_z$','^zone_change_atmpt$','^za_inner_outer_ho$','^za_outer_inner_ho$','^za_intra_zone_ho$','^za_tch_asn_iner_z$','^za_inter_ho_inner$','^zone_change_suc$','^zs_inner_outer_ho$','^zs_outer_inner_ho$','^zs_intra_zone_ho$','^zs_tch_asn_iner_z$','^zs_inter_ho_inner$' ],
'wRLCblkDLUNACK' => [ '^dl_rlc_nak_new_bks$','^dlrlcnanewbks_cs1$','^dlrlcnanewbks_cs2$','^dlrlcnanewbks_cs3$','^dlrlcnanewbks_cs4$','^dlrlcnanewbks_mcs1$','^dlrlcnanewbks_mcs2$','^dlrlcnanewbks_mcs3$','^dlrlcnanewbks_mcs4$','^dlrlcnanewbks_mcs6$','^dlrlcnanewbks_mcs5$','^dlrlcnanewbks_mcs7$','^dlrlcnanewbks_mcs8$','^dlrlcnanewbks_mcs9$' ],
'PFC_Rej_Ca' => [ '^pfc_reject_causes$','^pfc_max_ms_exceed$','^pfc_out_tbf_thp1$','^pfc_out_tbf_thp2$','^pfc_out_tbf_thp3$','^pfc_out_tbf_bgrnd$','^pfc_out_tbf_eff$','^pfc_out_tbf_sms$','^pfc_out_tbf_signal$','^pfc_out_tbf_pap$','^pfc_out_tbf_unawar$','^pfc_out_pfc_store$','^pfc_ms_capability$' ],
'Clear_req_MSC' => [ '^clr_req_call_s$','^call_s_pre_c_sd$','^call_s_pre_c_tch$','^call_s_post_c_sd$','^call_s_post_c_tch$' ],
'GPRS_Utiliza' => [ '^pdu_discard_llc$','^pdu_dscrdllc_cbuf$','^pdu_dscrdllc_msbuf$','^pdu_dscrdllc_mvpkt$','^pdu_dscrdllc_seq$','^pdu_dscrdllc_rslin$','^pdu_dscrdllc_rslot$','^pdu_dscrdllc_tbf$','^pdu_dscrdllc_rej$','^pacch_page_reqs$','^tbf_dl_asgn_pacch$','^tbf_rel_pacch_lost$','^cs1234_on_64k_chan$' ],
'Data_chnls_s_a' => [ '^ul_ch_asgn_1$','^ul_ch_asgn_2$','^ul_ch_asgn_3$','^ul_ch_asgn_4$','^ul_ch_asgn_5$','^ul_ch_asgn_6$','^ul_ch_asgn_7$','^ul_ch_asgn_8$','^dl_ch_asgn_1$','^dl_ch_asgn_2$','^dl_ch_asgn_3$','^dl_ch_asgn_4$','^dl_ch_asgn_5$','^dl_ch_asgn_6$','^dl_ch_asgn_7$','^dl_ch_asgn_8$' ],
'C_M_AMR_ad_FR' => [ '^amr_fr_ul_adapt$','^amr_fr_ul_adapt1_2$','^amr_fr_ul_adapt2_3$','^amr_fr_ul_adapt3_4$','^amr_fr_ul_adapt2_1$','^amr_fr_ul_adapt3_2$','^amr_fr_ul_adapt4_3$','^amr_fr_dl_adapt$','^amr_fr_dl_adapt1_2$','^amr_fr_dl_adapt2_3$','^amr_fr_dl_adapt3_4$','^amr_fr_dl_adapt2_1$','^amr_fr_dl_adapt3_2$','^amr_fr_dl_adapt4_3$' ],
'blkDLwith2TS' => [ '^dl_radio_blks_2_ts$','^dl_rf_bks_2ts_cs1$','^dl_rf_bks_2ts_cs2$','^dl_rf_bks_2ts_cs3$','^dl_rf_bks_2ts_cs4$','^dl_rf_bks_2ts_mcs1$','^dl_rf_bks_2ts_mcs2$','^dl_rf_bks_2ts_mcs3$','^dl_rf_bks_2ts_mcs4$','^dl_rf_bks_2ts_mcs5$','^dl_rf_bks_2ts_mcs6$','^dl_rf_bks_2ts_mcs7$','^dl_rf_bks_2ts_mcs8$','^dl_rf_bks_2ts_mcs9$' ],
'C_M_AMR_HR' => [ '^amr_h_ul_c_m_u$','^amr_h_ul_c_m_u795$','^amr_h_ul_c_m_u74$','^amr_h_ul_c_m_u67$','^amr_h_ul_c_m_u59$','^amr_h_ul_c_m_u515$','^amr_h_dl_c_m_u$','^amr_h_dl_c_m_u795$','^amr_h_dl_c_m_u74$','^amr_h_dl_c_m_u67$','^amr_h_dl_c_m_u59$','^amr_h_dl_c_m_u515$' ],
'RACH_requnserv' => [ '^g_rach_bts_tot$','^g_rach_bts_rsl$','^g_rach_bts_prr$','^g_rach_bts_agch$','^gprs_rach_arl_max$','^gprs_rach_arl_mean$','^gprs_rach_arl_min$' ],
'EGPRS_HO_2G_3G' => [ '^num_ho_to_3g_atts$','^num_ho2_3g_ressucc$','^num_ho_to_3g_succ$','^num_t3121_expiry$','^num_ho_fm_3g_atts$','^num_ho_fm_3g_succ$','^num_multrat_msorig$' ],
'GPRS_res_acc' => [ '^channel_reqs_rec$','^channel_reqs_rej$','^ch_reqs_succ$','^cell_flush_reqs$','^gbl_flow_ctrl_sent$','^codng_sch_chng_0$','^codng_sch_chng_1$','^codng_sch_chng_2$','^codng_sch_chng_3$','^codng_sch_chng_tot$','^cs12_on_32k_chan$','^gprs32k_ch_switch$','^gprs32k_dl_not_avl$','^gprs32k_ul_not_avl$','^gprs_acc_per_pch$','^gprs_acc_per_rach$','^gprs_acc_per_agch$','^gprscell_rsel_atpt$','^gprscell_rsel_fail$','^gprs_ch_switched$','^gprs_neigh_strong$','^pch_agch_q_ln_mean$','^pch_agch_q_ln_max$','^no_pdtch_avl_time$','^no_pdtch_avail$','^gprs_ch_swtch_cs$','^gprs_ch_swtch_vgcs$' ],
'General_ho' => [ '^assgn_redirect$','^dr_retry_ho$','^assgn_ho$','^mb_reassgn_ho$','^bad_ho_refnum_ms$','^ho_fail_no_rsourc$','^intra_bss$','^inter_bss$','^intra_cell$','^intra_bss_dynet$','^inter_bss_dynet$','^intra_cell_dynet$','^intra_cell_ho_suc$','^intra_cell_ho_los$','^intra_cell_ho_ret$','^i_inter_bs_ho_suc$','^o_intra_bs_ho_suc$','^o_intra_bs_ho_los$','^o_intra_bs_ho_ret$','^i_intra_bs_ho_suc$','^sdcch_ho_tot$','^sms_sdcch_ho_tot$' ],
'PFC_preemps' => [ '^pfc_preemptions$','^preemp_thp1_arp1$','^preemp_thp1_arp2$','^preemp_thp1_arp3$','^preemp_thp2_arp1$','^preemp_thp2_arp2$','^preemp_thp2_arp3$','^preemp_thp3_arp1$','^preemp_thp3_arp2$','^preemp_thp3_arp3$','^preemp_bgrn_arp1$','^preemp_bgrn_arp2$','^preemp_bgrn_arp3$','^preemp_eff_arp1$','^preemp_eff_arp2$','^preemp_eff_arp3$' ],
'Interfer_bands' => [ '^idl_tch_bnd0_max$','^idl_tch_bnd0_mean$','^idl_tch_bnd1_max$','^idl_tch_bnd1_mean$','^idl_tch_bnd2_max$','^idl_tch_bnd2_mean$','^idl_tch_bnd3_max$','^idl_tch_bnd3_mean$','^idl_tch_bnd4_max$','^idl_tch_bnd4_mean$' ],
'PPCH' => [ '^acc_per_ppch_tot$','^acc_per_ppch_cs_ps$','^acc_per_ppch_cs$','^acc_per_ppch_ps$','^ppch_q_pg_dis_tot$','^ppch_q_pg_dis_cs$','^ppch_q_pg_dis_ps$','^gprs_p_p_q_len_mn$','^gprs_p_p_q_len_mx$','^gprs_dl_asgn_p$' ],
'blkDLpreret' => [ '^dl_rlc_retx_blks$','^dlrlcretxblks_cs1$','^dlrlcretxblks_cs2$','^dlrlcretxblks_cs3$','^dlrlcretxblks_cs4$','^dlrlcretxblks_mcs1$','^dlrlcretxblks_mcs2$','^dlrlcretxblks_mcs3$','^dlrlcretxblks_mcs4$','^dlrlcretxblks_mcs5$','^dlrlcretxblks_mcs6$','^dlrlcretxblks_mcs7$','^dlrlcretxblks_mcs8$','^dlrlcretxblks_mcs9$' ],
'Inter_cell_ho' => [ '^ohoa_upqual$','^ohoa_uplevel$','^ohoa_downqual$','^ohoa_downlevel$','^ohoa_distance$','^ohoa_upinterf$','^ohoa_downinterf$','^ohoa_powerbdgt$','^ohoa_congestion$','^ohoa_adj_chn_intf$','^ohoa_band_reasign$','^ohoa_bandhandover$','^sms_sdch_inter_c_h$' ],
'wRLCblkULUNACK' => [ '^ul_rlc_una_new_bks$','^ulrlcnanewbks_cs1$','^ulrlcnanewbks_cs2$','^ulrlcnanewbks_cs3$','^ulrlcnanewbks_cs4$','^ulrlcnanewbks_mcs1$','^ulrlcnanewbks_mcs2$','^ulrlcnanewbks_mcs3$','^ulrlcnanewbks_mcs4$','^ulrlcnanewbks_mcs5$','^ulrlcnanewbks_mcs6$','^ulrlcnanewbks_mcs7$','^ulrlcnanewbks_mcs8$','^ulrlcnanewbks_mcs9$' ],
'ewRLCblkDLACK' => [ '^dl_rlc_ack_new_bks$','^dlrlcaknewbks_cs1$','^dlrlcaknewbks_cs2$','^dlrlcaknewbks_cs3$','^dlrlcaknewbks_cs4$','^dlrlcaknewbks_mcs1$','^dlrlcaknewbks_mcs2$','^dlrlcaknewbks_mcs3$','^dlrlcaknewbks_mcs4$','^dlrlcaknewbks_mcs5$','^dlrlcaknewbks_mcs6$','^dlrlcaknewbks_mcs7$','^dlrlcaknewbks_mcs8$','^dlrlcaknewbks_mcs9$' ],
'blkDLretrwns' => [ '^dl_rlc_stalld_blks$','^dlrlcstaldbks_cs1$','^dlrlcstaldbks_cs2$','^dlrlcstaldbks_cs3$','^dlrlcstaldbks_cs4$','^dlrlcstaldbks_mcs1$','^dlrlcstaldbks_mcs2$','^dlrlcstaldbks_mcs3$','^dlrlcstaldbks_mcs4$','^dlrlcstaldbks_mcs5$','^dlrlcstaldbks_mcs6$','^dlrlcstaldbks_mcs7$','^dlrlcstaldbks_mcs8$','^dlrlcstaldbks_mcs9$' ],
'Data_blk_p_cod' => [ '^air_dl_cntrl_blks$','^air_ul_cntrl_blks$','^air_ul_data_blks$','^air_ul_blks_q1_cs1$','^air_ul_blks_q2_cs1$','^air_ul_blks_q3_cs1$','^air_ul_blks_q4_cs1$','^air_ul_blks_q1_cs2$','^air_ul_blks_q2_cs2$','^air_ul_blks_q3_cs2$','^air_ul_blks_q4_cs2$','^air_ul_blks_q1_cs3$','^air_ul_blks_q2_cs3$','^air_ul_blks_q3_cs3$','^air_ul_blks_q1_cs4$','^air_ul_blks_q2_cs4$','^air_ul_blks_q3_cs4$','^air_dl_data_blks$','^air_dl_blks_q1_cs1$','^air_dl_blks_q2_cs1$','^air_dl_blks_q3_cs1$','^air_dl_blks_q4_cs1$','^air_dl_blks_q1_cs2$','^air_dl_blks_q2_cs2$','^air_dl_blks_q3_cs2$','^air_dl_blks_q4_cs2$','^air_dl_blks_q1_cs3$','^air_dl_blks_q2_cs3$','^air_dl_blks_q3_cs3$','^air_dl_blks_q1_cs4$','^air_dl_blks_q2_cs4$','^air_dl_blks_q3_cs4$','^ttl_air_ul_avail$','^ttl_air_dl_avail$' ],
'Intra_cell_ho' => [ '^intra_cell_ho_suc$','^intra_cell_ho_req$','^intra_cell_ho_atm$','^intra_cell_ho_atmpt_fr_fr$','^intra_cell_ho_atmpt_hr_hr$','^intra_cell_ho_atmpt_hr_fr$','^intra_cell_ho_atmpt_fr_hr$','^intra_cell_ho_f_f$','^intra_cell_ho_h_h$','^intra_cell_ho_h_f$','^intra_cell_ho_f_h$','^intra_cell_ho_ret$','^intra_cell_ho_los$','^intra_cell_ho_clr$','^intra_cell_eqp_fa$','^intra_cell_ho_s_s$','^sms_sdch_intra_c_h$' ],
'Pkt_dat_traf_c' => [ '^avail_pdtch_mean$','^avail_pdtch_max$','^dl_busy_pdtch_mean$','^dl_busy_pdtch_max$','^dl_busy_pdtch_min$','^dl_pdtch_con_tot$','^dl_pdtch_q_len_mn$','^dl_pdtch_q_len_mx$','^dl_pdtch_seizure$','^ul_busy_pdtch_mean$','^ul_busy_pdtch_min$','^ul_busy_pdtch_max$','^ul_pdtch_con_tot$','^ul_pdtch_q_len_mn$','^ul_pdtch_q_len_mx$','^ul_pdtch_seizure$' ],
'DL_LLC_Data' => [ '^dl_llc_data_vol$','^dlllcvol_thp1_arp1$','^dlllcvol_thp1_arp2$','^dlllcvol_thp1_arp3$','^dlllcvol_thp2_arp1$','^dlllcvol_thp2_arp2$','^dlllcvol_thp2_arp3$','^dlllcvol_thp3_arp1$','^dlllcvol_thp3_arp2$','^dlllcvol_thp3_arp3$','^dlllcvol_bgrn_arp1$','^dlllcvol_bgrn_arp2$','^dlllcvol_bgrn_arp3$','^dlllcvol_eff_arp1$','^dlllcvol_eff_arp2$','^dlllcvol_eff_arp3$' ],
'PFC_RejDwngCll' => [ '^pfc_rej_dgrd_prmpt$','^pfc_rej_cell_res$','^pfc_rej_prp_res$','^pfc_down_cell_res$','^pfc_down_prp_res$','^pfc_preem_cell_res$','^pfc_preem_prp_res$','^pfc_down_cell_ret$','^pfc_down_prp_ret$','^pfc_preem_cell_ret$','^pfc_preem_prp_ret$' ],
'blkULwith2TS' => [ '^ul_rf_bks_gmsk_2ts$','^ulrfbkgmsk2ts_cs1$','^ulrfbkgmsk2ts_cs2$','^ulrfbkgmsk2ts_cs3$','^ulrfbkgmsk2ts_cs4$','^ulrfbkgmsk2ts_mcs1$','^ulrfbkgmsk2ts_mcs2$','^ulrfbkgmsk2ts_mcs3$','^ulrfbkgmsk2ts_mcs4$' ],
'HR_agnm_fm_MSC' => [ '^ma_req_pm_gsm_hr$','^ma_comp_pm_gsm_hr$','^ho_req_pm_gsm_hr$','^ho_ack_pm_gsm_hr$' ],
'blkDLwith1TS' => [ '^dl_radio_blks_1_ts$','^dl_rf_bks_1ts_cs1$','^dl_rf_bks_1ts_cs2$','^dl_rf_bks_1ts_cs3$','^dl_rf_bks_1ts_cs4$','^dl_rf_bks_1ts_mcs1$','^dl_rf_bks_1ts_mcs2$','^dl_rf_bks_1ts_mcs3$','^dl_rf_bks_1ts_mcs4$','^dl_rf_bks_1ts_mcs5$','^dl_rf_bks_1ts_mcs6$','^dl_rf_bks_1ts_mcs7$','^dl_rf_bks_1ts_mcs8$','^dl_rf_bks_1ts_mcs9$' ],
'HO_from_MSC' => [ '^ho_req_f_msc_tot$','^ho_req_f_msc_fr$','^ho_req_f_msc_e_fr$','^ho_req_f_msc_a_fr$','^ho_req_f_msc_a_hr$','^ho_req_f_msc_s_c$','^ho_req_f_msc_otr$' ],
'MA_cmpl_to_MSC' => [ '^ma_com_to_msc_fr$','^ma_com_to_msc_e_fr$','^ma_com_to_msc_a_fr$','^ma_com_to_msc_a_hr$','^ma_com_to_msc_s_c$','^ma_com_to_msc_otr$','^ma_rq_sdcch_pg_rsp$' ],
'TCH_assig' => [ '^ma_req_from_msc$','^ma_cmd_to_ms$','^ma_cmd_to_ms_blkd$','^ma_fail_from_ms$','^tch_q_removed$','^assgn_res_req$','^ho_req$','^i_inter_bs_ho_suc$','^i_intra_bs_ho_suc$','^total_calls$' ],
'PFC_Rej' => [ '^pfc_admreject$','^pfcadmrej_thp1arp1$','^pfcadmrej_thp1arp2$','^pfcadmrej_thp1arp3$','^pfcadmrej_thp2arp1$','^pfcadmrej_thp2arp2$','^pfcadmrej_thp2arp3$','^pfcadmrej_thp3arp1$','^pfcadmrej_thp3arp2$','^pfcadmrej_thp3arp3$','^pfcadmrej_bgrnarp1$','^pfcadmrej_bgrnarp2$','^pfcadmrej_bgrnarp3$','^pfcadmrej_effarp1$','^pfcadmrej_effarp2$','^pfcadmrej_effarp3$' ],
'Multiband' => [ '^interband_activty$','^ia_pgsm_ho_atm$','^ia_egsm_ho_atm$','^ia_dcs1800_atm$','^ia_dcs2000_atm$','^ia_pgsm_ho_fail$','^ia_egsm_ho_fail$','^ia_dcs1800_fail$','^ia_dcs2000_fail$','^ia_invld_frq_as$','^ia_invld_frq_ho$','^mat_pgsm_only$','^mat_dcs1800_only$','^mat_dcs2000_only$','^mat_pgsm_egsm$','^mat_pgsm_dcs1800$','^mat_pegsm_dcs1800$','^mat_pgsm_dcs2000$','^mat_pegsm_dcs2000$','^ms_tch_usg_type$','^mtu_pgsm_only$','^mtu_dcs1800_only$','^mtu_dcs2000_only$','^mtu_pgsm_egsm$','^mtu_pgsm_dcs1800$','^mtu_pegsm_dcs1800$','^mtu_pgsm_dcs2000$','^mtu_pegsm_dcs2000$','^ms_access_type$' ],
'GPRS_Cong' => [ '^gprs_cell_congest$','^gprs_cellcong_25$','^gprs_cellcong_30$','^gprs_cellcong_35$','^gprs_cellcong_40$','^gprs_cellcong_45$','^gprs_cellcong_50$','^gprs_cellcong_55$','^gprs_cellcong_60$','^gprs_cellcong_65$','^gprs_cellcong_70$','^gprs_cellcong_75$','^gprs_cellcong_80$','^gprs_cellcong_85$','^gprs_cellcong_90$','^gprs_cellcong_95$','^gprs_cellcong_100$' ],

},
ONLY_INSERT => [ qw(nodeid btsid cellid gsmcellid xcellid cellname network_id start end day DURATION START_DATE START_TIME PERIOD END_TIME) ],
REDUNDANT_DATA_COUNTERS    => [],
PRODUCE_PIF                => 'True',
PRODUCE_LIF                => 0,
},

#Output ewRLCblkULACK block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output ewRLCblkULACK block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-ewRLCblkULACK-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'ewRLCblkULACK',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output MS_clas_1_t_29 block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output MS_clas_1_t_29 block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-MS_clas_1_t_29-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'MS_clas_1_t_29',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Dur_UL_DL_TBFs block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Dur_UL_DL_TBFs block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Dur_UL_DL_TBFs-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Dur_UL_DL_TBFs',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output pkt_reqs block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output pkt_reqs block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-pkt_reqs-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'pkt_reqs',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Intra_BSS_ho block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Intra_BSS_ho block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Intra_BSS_ho-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Intra_BSS_ho',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Imm_assig_proc block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Imm_assig_proc block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Imm_assig_proc-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Imm_assig_proc',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output EGPRS_codschch block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output EGPRS_codschch block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-EGPRS_codschch-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'EGPRS_codschch',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output UL_LLC_Data block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output UL_LLC_Data block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-UL_LLC_Data-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'UL_LLC_Data',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkULwith1TS block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkULwith1TS block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkULwith1TS-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkULwith1TS',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Dwng_Suc block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Dwng_Suc block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Dwng_Suc-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Dwng_Suc',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_trup_Ulcell block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trup_Ulcell block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-GPRS_trup_Ulcell-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trup_Ulcell',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Upg block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Upg block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Upg-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Upg',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output C_M_AMR_FR block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output C_M_AMR_FR block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-C_M_AMR_FR-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'C_M_AMR_FR',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Inter_BSS_ho block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Inter_BSS_ho block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Inter_BSS_ho-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Inter_BSS_ho',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output HO_acks_to_MSC block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output HO_acks_to_MSC block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-HO_acks_to_MSC-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'HO_acks_to_MSC',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkDLexpNACK block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkDLexpNACK block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkDLexpNACK-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkDLexpNACK',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output bkUL2TSwo8PK block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output bkUL2TSwo8PK block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-bkUL2TSwo8PK-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'bkUL2TSwo8PK',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output C_M_AMR_ad_HR block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output C_M_AMR_ad_HR block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-C_M_AMR_ad_HR-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'C_M_AMR_ad_HR',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Directed_retry block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Directed_retry block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Directed_retry-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Directed_retry',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkDLwith4TS block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkDLwith4TS block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkDLwith4TS-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkDLwith4TS',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output pktresreqblkus block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output pktresreqblkus block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-pktresreqblkus-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'pktresreqblkus',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Dummy_LLCs block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Dummy_LLCs block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Dummy_LLCs-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Dummy_LLCs',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Call_clearing block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Call_clearing block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Call_clearing-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Call_clearing',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output pkt_Response block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output pkt_Response block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-pkt_Response-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'pkt_Response',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output AMR_TCH block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output AMR_TCH block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-AMR_TCH-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'AMR_TCH',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output chnl_req block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output chnl_req block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-chnl_req-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'chnl_req',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Dwng_fails block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Dwng_fails block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Dwng_fails-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Dwng_fails',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkULretran block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkULretran block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkULretran-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkULretran',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blked_TBF block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blked_TBF block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blked_TBF-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blked_TBF',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output FR_agnm_frmMSC block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output FR_agnm_frmMSC block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-FR_agnm_frmMSC-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'FR_agnm_frmMSC',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output preemp_Service block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output preemp_Service block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-preemp_Service-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'preemp_Service',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Idle_UL_PDTCH block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Idle_UL_PDTCH block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Idle_UL_PDTCH-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Idle_UL_PDTCH',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output EGPRS_chnl_res block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output EGPRS_chnl_res block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-EGPRS_chnl_res-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'EGPRS_chnl_res',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Simult_TBF block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Simult_TBF block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Simult_TBF-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Simult_TBF',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Pag_req_msg block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Pag_req_msg block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Pag_req_msg-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Pag_req_msg',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output conn_estab block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output conn_estab block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-conn_estab-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'conn_estab',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output C_M_AMR_adjust block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output C_M_AMR_adjust block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-C_M_AMR_adjust-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'C_M_AMR_adjust',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_chl_unsrv block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_chl_unsrv block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-GPRS_chl_unsrv-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_chl_unsrv',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Calls_lt_onTCH block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Calls_lt_onTCH block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Calls_lt_onTCH-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Calls_lt_onTCH',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output TBF_fails_pr_c block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output TBF_fails_pr_c block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-TBF_fails_pr_c-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'TBF_fails_pr_c',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkDLwith3TS block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkDLwith3TS block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkDLwith3TS-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkDLwith3TS',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Timer_Expiry block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Timer_Expiry block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Timer_Expiry-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Timer_Expiry',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Admission block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Admission block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Admission-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Admission',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Emerg_call_acc block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Emerg_call_acc block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Emerg_call_acc-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Emerg_call_acc',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Ext_range_cell block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Ext_range_cell block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Ext_range_cell-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Ext_range_cell',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output CellPDTCHav block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output CellPDTCHav block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-CellPDTCHav-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'CellPDTCHav',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Rej_Oth block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Rej_Oth block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Rej_Oth-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Rej_Oth',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output cell_stats block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output cell_stats block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-cell_stats-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'cell_stats',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output TCH_inner_zone block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output TCH_inner_zone block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-TCH_inner_zone-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'TCH_inner_zone',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkULTSwo8PK block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkULTSwo8PK block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkULTSwo8PK-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkULTSwo8PK',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Admi_Other block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Admi_Other block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Admi_Other-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Admi_Other',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_trup_Dlcell block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trup_Dlcell block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-GPRS_trup_Dlcell-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trup_Dlcell',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Nw_As_Chn block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Nw_As_Chn block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Nw_As_Chn-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Nw_As_Chn',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Concent_cell block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Concent_cell block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Concent_cell-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Concent_cell',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output wRLCblkDLUNACK block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output wRLCblkDLUNACK block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-wRLCblkDLUNACK-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'wRLCblkDLUNACK',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Rej_Ca block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Rej_Ca block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Rej_Ca-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Rej_Ca',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Clear_req_MSC block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Clear_req_MSC block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Clear_req_MSC-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Clear_req_MSC',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_Utiliza block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_Utiliza block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-GPRS_Utiliza-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_Utiliza',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Data_chnls_s_a block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Data_chnls_s_a block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Data_chnls_s_a-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Data_chnls_s_a',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output C_M_AMR_ad_FR block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output C_M_AMR_ad_FR block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-C_M_AMR_ad_FR-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'C_M_AMR_ad_FR',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkDLwith2TS block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkDLwith2TS block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkDLwith2TS-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkDLwith2TS',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output C_M_AMR_HR block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output C_M_AMR_HR block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-C_M_AMR_HR-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'C_M_AMR_HR',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output RACH_requnserv block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output RACH_requnserv block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-RACH_requnserv-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'RACH_requnserv',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output EGPRS_HO_2G_3G block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output EGPRS_HO_2G_3G block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-EGPRS_HO_2G_3G-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'EGPRS_HO_2G_3G',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_res_acc block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_res_acc block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-GPRS_res_acc-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_res_acc',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output General_ho block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output General_ho block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-General_ho-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'General_ho',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_preemps block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_preemps block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_preemps-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_preemps',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Interfer_bands block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Interfer_bands block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Interfer_bands-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Interfer_bands',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PPCH block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PPCH block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PPCH-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PPCH',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkDLpreret block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkDLpreret block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkDLpreret-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkDLpreret',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Inter_cell_ho block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Inter_cell_ho block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Inter_cell_ho-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Inter_cell_ho',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output wRLCblkULUNACK block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output wRLCblkULUNACK block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-wRLCblkULUNACK-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'wRLCblkULUNACK',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output ewRLCblkDLACK block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output ewRLCblkDLACK block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-ewRLCblkDLACK-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'ewRLCblkDLACK',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkDLretrwns block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkDLretrwns block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkDLretrwns-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkDLretrwns',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Data_blk_p_cod block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Data_blk_p_cod block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Data_blk_p_cod-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Data_blk_p_cod',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Intra_cell_ho block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Intra_cell_ho block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Intra_cell_ho-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Intra_cell_ho',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Pkt_dat_traf_c block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Pkt_dat_traf_c block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Pkt_dat_traf_c-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Pkt_dat_traf_c',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output DL_LLC_Data block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output DL_LLC_Data block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-DL_LLC_Data-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'DL_LLC_Data',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_RejDwngCll block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_RejDwngCll block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_RejDwngCll-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_RejDwngCll',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkULwith2TS block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkULwith2TS block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkULwith2TS-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkULwith2TS',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output HR_agnm_fm_MSC block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output HR_agnm_fm_MSC block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-HR_agnm_fm_MSC-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'HR_agnm_fm_MSC',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output blkDLwith1TS block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output blkDLwith1TS block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-blkDLwith1TS-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'blkDLwith1TS',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output HO_from_MSC block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output HO_from_MSC block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-HO_from_MSC-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'HO_from_MSC',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output MA_cmpl_to_MSC block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output MA_cmpl_to_MSC block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-MA_cmpl_to_MSC-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'MA_cmpl_to_MSC',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output TCH_assig block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output TCH_assig block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-TCH_assig-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'TCH_assig',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output PFC_Rej block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output PFC_Rej block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-PFC_Rej-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'PFC_Rej',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Multiband block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Multiband block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-Multiband-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Multiband',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_Cong block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_Cong block',
INPUT_FILE_DESCRIPTION     => '^all_cell-#-.+-#-J-#-PL-#-GPRS_Cong-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_Cong',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},



#{
#RULE_TYPE => 'FILE_SPLIT',
#RULE_DESC => "Split cell_stats based on nodeid",
#INPUT_FILE_DESCRIPTION => ['all_cell-#-.+-#-J-#-PL.pif'],
#COUNTERS_USED_TO_SPLIT_FILE => {
#	#'cellid' => '(.+)',
#	'nodeid' => '(.+)',
#	'day' => '(.+)',
#	'start' => '(.+)',
#	'end' => '(.+)',
#	},
#SPLIT_COUNTERS_ORDER => [ qw(day start end nodeid) ],
#PRODUCE_PIF => 0,
#PRODUCE_LIF => "True",
##OUTPUT_BLOCK_NAME => 'FS',
#REDUNDANT_DATA_COUNTERS => [],
#},

{
RULE_TYPE => 'PERLIZE',
RULE_DESC => 'Remove all counters except BSC_ALL required cntrs',
INPUT_FILE_DESCRIPTION => '^all_cell.*-#-J.pif',
DATA_COUNTERS_OP => sub
{
	my $c_ref = shift;
 	my($key_str)="";	
	foreach $key_str (keys(%$c_ref))
	{
		if ( ($key_str ne 'day' )
		   && ($key_str ne 'start' )
		   && ($key_str ne 'end' )
		   && ($key_str ne 'busy_sdcch_mean' )
		   && ($key_str ne 'busy_tch_mean' )
		   && ($key_str ne 'air_ul_cntrl_blks' )
		   && ($key_str ne 'air_dl_cntrl_blks' )
		   && ($key_str ne 'nodeid' )
		   && ($key_str ne 'air_ul_data_blks' )
		   && ($key_str ne 'DURATION' )
		   && ($key_str ne 'START_DATE' )
		   && ($key_str ne 'START_TIME' )
		   && ($key_str ne 'END_TIME' )
		   && ($key_str ne 'PERIOD' )
		   && ($key_str ne 'air_dl_data_blks' ) )
		   {
			delete($$c_ref{$key_str});
		   }
	}
# all okay
return 0;
},
FILENAME_SUFFIX => 'RCNT',
PRODUCE_LIF => 0,
PRODUCE_PIF => 'TRUE',
OUTPUT_BLOCK_NAME => 'cell_stats',
},


{
'RULE_TYPE'              => 'ACCUMULATE',
'RULE_DESC'              => 'Aggregate all_cell',
'PRODUCE_PIF'            => 0,
'PRODUCE_LIF'            => 'True',
'OUTPUT_BLOCK_NAME'      => 'BSC_ALL',
'OUTPUT_FILENAME_START' => 'BSC_ALL',
'INPUT_FILE_DESCRIPTION' => ['^all_cell-#-.*-#-J-#-RCNT.pif'],
        #'INPUT_FILE_DESCRIPTION' => ['all_cell-#-(\w+)\.(\w*)\.(\d{1,2}\w{3,4}\d{4})\.(\d{2}[\_:]\d{2}[\_:]\d{2})\.(\d+)-#-.*-#-J-#-PL-#-BSC_ALL-#-A.pif'],
'COUNTERS_TO_SORT_ON'    => ['nodeid'],
'NON_ADDITIVE_COUNTERS'  => ['start','end','day','DURATION','START_DATE','START_TIME','PERIOD','END_TIME'],
'REDUNDANT_COUNTERS'     => [],
},


{
RULE_TYPE => 'PERLIZE',
RULE_DESC => 'remove unnecessary fer_amr_fr* counters from carrier1 lifs',
INPUT_FILE_DESCRIPTION => '^carrier_stats[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$', 
DATA_COUNTERS_OP => sub
{
my $c_ref = shift;
my($key_str)="";	
foreach $key_str (keys(%$c_ref))
{
	if ($key_str =~ /^fer_amr_fr_.+$/ )
	{
		delete($$c_ref{$key_str});
	}	
}
# all okay
return 0;
},
FILENAME_SUFFIX => 'RCNT',
PRODUCE_LIF => 0,
PRODUCE_PIF => 'True',
OUTPUT_BLOCK_NAME => 'carrier_stats',
},


{
'RULE_TYPE' => 'JOIN',
'RULE_DESC' => 'Merging carrier_stats and carrier_stats5',
'INPUT_FILE_DESCRIPTION' => [ 
'^carrier_stats[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS-#-RCNT.pif$',
#'^carrier_stats2[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$',
#'^carrier_stats3[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$',
'^carrier_stats4[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$',
'^carrier_stats5[\.\_]\w+\.{0,1}\d{1,2}\w{3,4}\d{4}\..+-I-#-(.+)-#-FS.pif$',],
#'^(.*)cgprs_stats.*-#-I.pif' ],
'PRODUCE_PIF' => 'True',
'PRODUCE_LIF' => 0,
'OUTPUT_BLOCK_NAME' => 'carrier_stats',
'COUNTERS_TO_JOIN_ON' => ['nodeid', 'cellid','carrierid'],
'OUTPUT_FILENAME_START' => 'carrier_stats',
'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ['FILENAME'],
},


{
    RULE_TYPE                   => 'FILE_SPLIT_BY_COUNTERS',
    RULE_DESC                   => 'Split Carrier object counters into respective blocks',
    INPUT_FILE_DESCRIPTION      => 'carrier_stats-#-.+-#-J.pif',
    SPLIT_CNAMES => {

	'GPRS_trDL_MCS_1' => [ '^dl_bler_mcs1$','^dl_bler_mcs1_5$','^dl_bler_mcs1_10$','^dl_bler_mcs1_15$','^dl_bler_mcs1_20$','^dl_bler_mcs1_25$','^dl_bler_mcs1_30$','^dl_bler_mcs1_40$','^dl_bler_mcs1_100$','^dl_bler_mcs2$','^dl_bler_mcs2_10$','^dl_bler_mcs2_20$','^dl_bler_mcs2_25$','^dl_bler_mcs2_30$','^dl_bler_mcs2_35$','^dl_bler_mcs2_40$','^dl_bler_mcs2_65$','^dl_bler_mcs2_100$','^dl_bler_mcs3$','^dl_bler_mcs3_15$','^dl_bler_mcs3_25$','^dl_bler_mcs3_30$','^dl_bler_mcs3_35$','^dl_bler_mcs3_40$','^dl_bler_mcs3_45$','^dl_bler_mcs3_70$','^dl_bler_mcs3_100$','^dl_bler_mcs4$','^dl_bler_mcs4_20$','^dl_bler_mcs4_35$','^dl_bler_mcs4_40$','^dl_bler_mcs4_45$','^dl_bler_mcs4_50$','^dl_bler_mcs4_55$','^dl_bler_mcs4_65$','^dl_bler_mcs4_100$','^dl_bler_mcs5$','^dl_bler_mcs5_15$','^dl_bler_mcs5_25$','^dl_bler_mcs5_30$','^dl_bler_mcs5_35$','^dl_bler_mcs5_40$','^dl_bler_mcs5_45$','^dl_bler_mcs5_70$','^dl_bler_mcs5_100$' ],
'GPRS_trDL_MCS_2' => [ '^dl_bler_mcs6$','^dl_bler_mcs6_15$','^dl_bler_mcs6_30$','^dl_bler_mcs6_35$','^dl_bler_mcs6_40$','^dl_bler_mcs6_45$','^dl_bler_mcs6_50$','^dl_bler_mcs6_75$','^dl_bler_mcs6_100$','^dl_bler_mcs7$','^dl_bler_mcs7_20$','^dl_bler_mcs7_35$','^dl_bler_mcs7_40$','^dl_bler_mcs7_45$','^dl_bler_mcs7_50$','^dl_bler_mcs7_55$','^dl_bler_mcs7_80$','^dl_bler_mcs7_100$','^dl_bler_mcs8$','^dl_bler_mcs8_20$','^dl_bler_mcs8_35$','^dl_bler_mcs8_40$','^dl_bler_mcs8_45$','^dl_bler_mcs8_50$','^dl_bler_mcs8_55$','^dl_bler_mcs8_80$','^dl_bler_mcs8_100$','^dl_bler_mcs9$','^dl_bler_mcs9_20$','^dl_bler_mcs9_35$','^dl_bler_mcs9_40$','^dl_bler_mcs9_45$','^dl_bler_mcs9_50$','^dl_bler_mcs9_55$','^dl_bler_mcs9_80$','^dl_bler_mcs9_100$' ],
'carrier_stats4' => [ '^u_ber_min0$','^u_ber_min1$','^u_ber_min2$','^u_ber_min3$','^u_ber_min4$','^u_ber_min5$','^u_ber_min6$','^u_ber_min7$','^u_ber_mean0$','^u_ber_mean1$','^u_ber_mean2$','^u_ber_mean3$','^u_ber_mean4$','^u_ber_mean5$','^u_ber_mean6$','^u_ber_mean7$','^u_ber_max0$','^u_ber_max1$','^u_ber_max2$','^u_ber_max3$','^u_ber_max4$','^u_ber_max5$','^u_ber_max6$','^u_ber_max7$' ],
'FER_RXQUAL_ov' => [ '^fer_min0$','^fer_min1$','^fer_min2$','^fer_min3$','^fer_min4$','^fer_min5$','^fer_min6$','^fer_min7$','^fer_mean0$','^fer_mean1$','^fer_mean2$','^fer_mean3$','^fer_mean4$','^fer_mean5$','^fer_mean6$','^fer_mean7$','^fer_max0$','^fer_max1$','^fer_max2$','^fer_max3$','^fer_max4$','^fer_max5$','^fer_max6$','^fer_max7$' ],
'CalllostAMRHRTC' => [ '^bsy_tch_c_hr_a_max$','^bsy_tch_c_hr_a_mn$','^rf_los_tch_hr_amr0$','^rf_los_tch_hr_amr1$','^rf_los_tch_hr_amr2$','^rf_los_tch_hr_amr3$','^rf_los_tch_hr_amr4$','^rf_los_tch_hr_amr5$','^rf_los_tch_hr_amr6$','^rf_los_tch_hr_amr7$' ],
'BER_DL_RXQUALov' => [ '^ber_min0$','^ber_min1$','^ber_min2$','^ber_min3$','^ber_min4$','^ber_min5$','^ber_min6$','^ber_min7$','^ber_mean0$','^ber_mean1$','^ber_mean2$','^ber_mean3$','^ber_mean4$','^ber_mean5$','^ber_mean6$','^ber_mean7$','^ber_max0$','^ber_max1$','^ber_max2$','^ber_max3$','^ber_max4$','^ber_max5$','^ber_max6$','^ber_max7$' ],
'GPRS_trUL_MCS_1' => [ '^ul_bler_mcs1$','^ul_bler_mcs1_5$','^ul_bler_mcs1_10$','^ul_bler_mcs1_15$','^ul_bler_mcs1_20$','^ul_bler_mcs1_25$','^ul_bler_mcs1_30$','^ul_bler_mcs1_40$','^ul_bler_mcs1_100$','^ul_bler_mcs2$','^ul_bler_mcs2_10$','^ul_bler_mcs2_20$','^ul_bler_mcs2_25$','^ul_bler_mcs2_30$','^ul_bler_mcs2_35$','^ul_bler_mcs2_40$','^ul_bler_mcs2_65$','^ul_bler_mcs2_100$','^ul_bler_mcs3$','^ul_bler_mcs3_15$','^ul_bler_mcs3_25$','^ul_bler_mcs3_30$','^ul_bler_mcs3_35$','^ul_bler_mcs3_40$','^ul_bler_mcs3_45$','^ul_bler_mcs3_70$','^ul_bler_mcs3_100$','^ul_bler_mcs4$','^ul_bler_mcs4_20$','^ul_bler_mcs4_35$','^ul_bler_mcs4_40$','^ul_bler_mcs4_45$','^ul_bler_mcs4_50$','^ul_bler_mcs4_55$','^ul_bler_mcs4_65$','^ul_bler_mcs4_100$','^ul_bler_mcs5$','^ul_bler_mcs5_15$','^ul_bler_mcs5_25$','^ul_bler_mcs5_30$','^ul_bler_mcs5_35$','^ul_bler_mcs5_40$','^ul_bler_mcs5_45$','^ul_bler_mcs5_70$','^ul_bler_mcs5_100$' ],
'GPRS_trUL_MCS_2' => [ '^ul_bler_mcs6$','^ul_bler_mcs6_15$','^ul_bler_mcs6_30$','^ul_bler_mcs6_35$','^ul_bler_mcs6_40$','^ul_bler_mcs6_45$','^ul_bler_mcs6_50$','^ul_bler_mcs6_75$','^ul_bler_mcs6_100$','^ul_bler_mcs7$','^ul_bler_mcs7_20$','^ul_bler_mcs7_35$','^ul_bler_mcs7_40$','^ul_bler_mcs7_45$','^ul_bler_mcs7_50$','^ul_bler_mcs7_55$','^ul_bler_mcs7_80$','^ul_bler_mcs7_100$','^ul_bler_mcs8$','^ul_bler_mcs8_20$','^ul_bler_mcs8_35$','^ul_bler_mcs8_40$','^ul_bler_mcs8_45$','^ul_bler_mcs8_50$','^ul_bler_mcs8_55$','^ul_bler_mcs8_80$','^ul_bler_mcs8_100$','^ul_bler_mcs9$','^ul_bler_mcs9_20$','^ul_bler_mcs9_35$','^ul_bler_mcs9_40$','^ul_bler_mcs9_45$','^ul_bler_mcs9_50$','^ul_bler_mcs9_55$','^ul_bler_mcs9_80$','^ul_bler_mcs9_100$' ],
'GSMHRfrms_undcd' => [ '^fer_gsm_hr_mean$','^fer_gsm_hr_bin1$','^fer_gsm_hr_min$','^fer_gsm_hr_bin5$','^fer_gsm_hr_bin2$','^fer_gsm_hr_bin7$','^fer_gsm_hr_bin3$','^fer_gsm_hr_bin9$','^fer_gsm_hr_max$','^fer_gsm_hr_bin8$','^fer_gsm_hr_bin6$','^fer_gsm_hr_bin0$','^fer_gsm_hr_bin4$' ],
'GPRS_trup_DL' => [ '^dl_bler_cs1$','^dl_bler_cs1_5$','^dl_bler_cs1_10$','^dl_bler_cs1_15$','^dl_bler_cs1_20$','^dl_bler_cs1_25$','^dl_bler_cs1_30$','^dl_bler_cs1_40$','^dl_bler_cs1_100$','^dl_bler_cs2$','^dl_bler_cs2_10$','^dl_bler_cs2_20$','^dl_bler_cs2_25$','^dl_bler_cs2_30$','^dl_bler_cs2_35$','^dl_bler_cs2_40$','^dl_bler_cs2_65$','^dl_bler_cs2_100$','^dl_bler_cs3$','^dl_bler_cs3_15$','^dl_bler_cs3_25$','^dl_bler_cs3_30$','^dl_bler_cs3_35$','^dl_bler_cs3_40$','^dl_bler_cs3_45$','^dl_bler_cs3_70$','^dl_bler_cs3_100$','^dl_bler_cs4$','^dl_bler_cs4_20$','^dl_bler_cs4_35$','^dl_bler_cs4_40$','^dl_bler_cs4_45$','^dl_bler_cs4_50$','^dl_bler_cs4_55$','^dl_bler_cs4_65$','^dl_bler_cs4_100$' ],
'Calls_lost_TCH' => [ '^rf_losses_tch0$','^rf_losses_tch1$','^rf_losses_tch2$','^rf_losses_tch3$','^rf_losses_tch4$','^rf_losses_tch5$','^rf_losses_tch6$','^rf_losses_tch7$','^busy_tch_max$','^busy_tch_mean$' ],
'GPRS_trup_UL' => [ '^ul_bler_cs1$','^ul_bler_cs1_5$','^ul_bler_cs1_10$','^ul_bler_cs1_15$','^ul_bler_cs1_20$','^ul_bler_cs1_25$','^ul_bler_cs1_30$','^ul_bler_cs1_40$','^ul_bler_cs1_100$','^ul_bler_cs2$','^ul_bler_cs2_10$','^ul_bler_cs2_20$','^ul_bler_cs2_25$','^ul_bler_cs2_30$','^ul_bler_cs2_35$','^ul_bler_cs2_40$','^ul_bler_cs2_65$','^ul_bler_cs2_100$','^ul_bler_cs3$','^ul_bler_cs3_15$','^ul_bler_cs3_25$','^ul_bler_cs3_30$','^ul_bler_cs3_35$','^ul_bler_cs3_40$','^ul_bler_cs3_45$','^ul_bler_cs3_70$','^ul_bler_cs3_100$','^ul_bler_cs4$','^ul_bler_cs4_20$','^ul_bler_cs4_35$','^ul_bler_cs4_40$','^ul_bler_cs4_45$','^ul_bler_cs4_50$','^ul_bler_cs4_55$','^ul_bler_cs4_65$','^ul_bler_cs4_100$' ],
'FER_AMR_FR' => [ '^fer_amr_fr_max$','^fer_amr_fr_mean$','^fer_amr_fr_min$','^fer_amr_fr_bin0$','^fer_amr_fr_bin1$','^fer_amr_fr_bin2$','^fer_amr_fr_bin3$','^fer_amr_fr_bin4$','^fer_amr_fr_bin5$','^fer_amr_fr_bin6$','^fer_amr_fr_bin7$','^fer_amr_fr_bin8$','^fer_amr_fr_bin9$' ],
'EGPRS_Carrier' => [ '^egprs_64kwdth_max$','^egprs_64kwdth_mean$','^ul_bckhal_dmd_max$','^ul_bckhal_dmd_mean$','^dl_bckhal_dmd_max$','^dl_bckhal_dmd_mean$','^ul_bckhal_usd_max$','^ul_bckhal_usd_mean$','^dl_bckhal_usd_max$','^dl_bckhal_usd_mean$' ],
'carrier_stats' => [ '^chanreq_fail_sdch0$','^chanreq_fail_sdch1$','^chanreq_fail_sdch2$','^chanreq_fail_sdch3$','^chanreq_fail_sdch4$','^chanreq_fail_sdch5$','^chanreq_fail_sdch6$','^chanreq_fail_sdch7$','^chanreq_fail_tchf0$','^chanreq_fail_tchf1$','^chanreq_fail_tchf2$','^chanreq_fail_tchf3$','^chanreq_fail_tchf4$','^chanreq_fail_tchf5$','^chanreq_fail_tchf6$','^chanreq_fail_tchf7$','^chanreq_fail_tchh0$','^chanreq_fail_tchh1$','^chanreq_fail_tchh2$','^chanreq_fail_tchh3$','^chanreq_fail_tchh4$','^chanreq_fail_tchh5$','^chanreq_fail_tchh6$','^chanreq_fail_tchh7$' ],
'TO_SDCCH_estab' => [ '^chan_req_ms_fail0$','^chan_req_ms_fail1$','^chan_req_ms_fail2$','^chan_req_ms_fail3$','^chan_req_ms_fail4$','^chan_req_ms_fail5$','^chan_req_ms_fail6$','^chan_req_ms_fail7$' ],
'Link_bal_verif' => [ '^ch_ul_tx_pwrl_min$','^ch_ul_tx_pwrl_max$','^ch_ul_tx_pwrl_mean$','^ch_dl_tx_pwrl_min$','^ch_dl_tx_pwrl_max$','^ch_dl_tx_pwrl_mean$','^uplink_path_min$','^uplink_path_max$','^uplink_path_mean$','^path_balance_min$','^path_balance_max$','^path_balance_mean$' ],
'FER_AMR_HR' => [ '^fer_amr_hr_max$','^fer_amr_hr_mean$','^fer_amr_hr_min$','^fer_amr_hr_bin0$','^fer_amr_hr_bin1$','^fer_amr_hr_bin2$','^fer_amr_hr_bin3$','^fer_amr_hr_bin4$','^fer_amr_hr_bin5$','^fer_amr_hr_bin6$','^fer_amr_hr_bin7$','^fer_amr_hr_bin8$','^fer_amr_hr_bin9$' ],
'FER_non_AMR' => [ '^fer_non_amr_max$','^fer_non_amr_mean$','^fer_non_amr_min$','^fer_non_amr_bin0$','^fer_non_amr_bin1$','^fer_non_amr_bin2$','^fer_non_amr_bin3$','^fer_non_amr_bin4$','^fer_non_amr_bin5$','^fer_non_amr_bin6$','^fer_non_amr_bin7$','^fer_non_amr_bin8$','^fer_non_amr_bin9$' ],
'Intrf_lvls_idle' => [ '^intf_on_idle_min0$','^intf_on_idle_min1$','^intf_on_idle_min2$','^intf_on_idle_min3$','^intf_on_idle_min4$','^intf_on_idle_min5$','^intf_on_idle_min6$','^intf_on_idle_min7$','^intf_on_idle_mean0$','^intf_on_idle_mean1$','^intf_on_idle_mean2$','^intf_on_idle_mean3$','^intf_on_idle_mean4$','^intf_on_idle_mean5$','^intf_on_idle_mean6$','^intf_on_idle_mean7$','^intf_on_idle_max0$','^intf_on_idle_max1$','^intf_on_idle_max2$','^intf_on_idle_max3$','^intf_on_idle_max4$','^intf_on_idle_max5$','^intf_on_idle_max6$','^intf_on_idle_max7$' ],
'BER_UL_RXQUALpl' => [ '^u_ber_bin0_ts0$','^u_ber_bin0_ts1$','^u_ber_bin0_ts2$','^u_ber_bin0_ts3$','^u_ber_bin0_ts4$','^u_ber_bin0_ts5$','^u_ber_bin0_ts6$','^u_ber_bin0_ts7$','^u_ber_bin1_ts0$','^u_ber_bin1_ts1$','^u_ber_bin1_ts2$','^u_ber_bin1_ts3$','^u_ber_bin1_ts4$','^u_ber_bin1_ts5$','^u_ber_bin1_ts6$','^u_ber_bin1_ts7$','^u_ber_bin2_ts0$','^u_ber_bin2_ts1$','^u_ber_bin2_ts2$','^u_ber_bin2_ts3$','^u_ber_bin2_ts4$','^u_ber_bin2_ts5$','^u_ber_bin2_ts6$','^u_ber_bin2_ts7$','^u_ber_bin3_ts0$','^u_ber_bin3_ts1$','^u_ber_bin3_ts2$','^u_ber_bin3_ts3$','^u_ber_bin3_ts4$','^u_ber_bin3_ts5$','^u_ber_bin3_ts6$','^u_ber_bin3_ts7$','^u_ber_bin4_ts0$','^u_ber_bin4_ts1$','^u_ber_bin4_ts2$','^u_ber_bin4_ts3$','^u_ber_bin4_ts4$','^u_ber_bin4_ts5$','^u_ber_bin4_ts6$','^u_ber_bin4_ts7$','^u_ber_bin5_ts0$','^u_ber_bin5_ts1$','^u_ber_bin5_ts2$','^u_ber_bin5_ts3$','^u_ber_bin5_ts4$','^u_ber_bin5_ts5$','^u_ber_bin5_ts6$','^u_ber_bin5_ts7$','^u_ber_bin6_ts0$','^u_ber_bin6_ts1$','^u_ber_bin6_ts2$','^u_ber_bin6_ts3$','^u_ber_bin6_ts4$','^u_ber_bin6_ts5$','^u_ber_bin6_ts6$','^u_ber_bin6_ts7$','^u_ber_bin7_ts0$','^u_ber_bin7_ts1$','^u_ber_bin7_ts2$','^u_ber_bin7_ts3$','^u_ber_bin7_ts4$','^u_ber_bin7_ts5$','^u_ber_bin7_ts6$','^u_ber_bin7_ts7$' ],
'Dyn_alloc_adv' => [ '^alloc_tch_carr$','^alloc_sdcch_carr$','^roc_min$','^roc_max$','^roc_mean$' ],
},
ONLY_INSERT => [ qw(nodeid btsid cellid gsmcellid xcellid cellname network_id carrierid start end day DURATION START_DATE START_TIME PERIOD END_TIME) ],
REDUNDANT_DATA_COUNTERS    => [],
PRODUCE_PIF                => 'True',
PRODUCE_LIF                => 0,
},

#Output GPRS_trDL_MCS_1 block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trDL_MCS_1 block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-GPRS_trDL_MCS_1-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trDL_MCS_1',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_trDL_MCS_2 block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trDL_MCS_2 block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-GPRS_trDL_MCS_2-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trDL_MCS_2',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output carrier_stats4 block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output carrier_stats4 block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-carrier_stats4-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'carrier_stats4',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output FER_RXQUAL_ov block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output FER_RXQUAL_ov block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-FER_RXQUAL_ov-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'FER_RXQUAL_ov',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output CalllostAMRHRTC block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output CalllostAMRHRTC block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-CalllostAMRHRTC-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'CalllostAMRHRTC',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output BER_DL_RXQUALov block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output BER_DL_RXQUALov block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-BER_DL_RXQUALov-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'BER_DL_RXQUALov',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_trUL_MCS_1 block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trUL_MCS_1 block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-GPRS_trUL_MCS_1-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trUL_MCS_1',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_trUL_MCS_2 block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trUL_MCS_2 block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-GPRS_trUL_MCS_2-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trUL_MCS_2',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GSMHRfrms_undcd block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GSMHRfrms_undcd block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-GSMHRfrms_undcd-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GSMHRfrms_undcd',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_trup_DL block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trup_DL block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-GPRS_trup_DL-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trup_DL',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Calls_lost_TCH block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Calls_lost_TCH block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-Calls_lost_TCH-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Calls_lost_TCH',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output GPRS_trup_UL block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output GPRS_trup_UL block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-GPRS_trup_UL-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'GPRS_trup_UL',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output FER_AMR_FR block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output FER_AMR_FR block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-FER_AMR_FR-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'FER_AMR_FR',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output EGPRS_Carrier block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output EGPRS_Carrier block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-EGPRS_Carrier-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'EGPRS_Carrier',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output carrier_stats block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output carrier_stats block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-carrier_stats-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'carrier_stats',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output TO_SDCCH_estab block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output TO_SDCCH_estab block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-TO_SDCCH_estab-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'TO_SDCCH_estab',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Link_bal_verif block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Link_bal_verif block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-Link_bal_verif-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Link_bal_verif',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output FER_AMR_HR block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output FER_AMR_HR block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-FER_AMR_HR-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'FER_AMR_HR',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output FER_non_AMR block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output FER_non_AMR block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-FER_non_AMR-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'FER_non_AMR',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Intrf_lvls_idle block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Intrf_lvls_idle block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-Intrf_lvls_idle-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Intrf_lvls_idle',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output BER_UL_RXQUALpl block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output BER_UL_RXQUALpl block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-BER_UL_RXQUALpl-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'BER_UL_RXQUALpl',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},
#Output Dyn_alloc_adv block
{
RULE_TYPE                  => 'PIF_2_OUTPUT',
RULE_DESC                  => 'Output Dyn_alloc_adv block',
INPUT_FILE_DESCRIPTION     => '^carrier_stats-#-.+-#-J-#-Dyn_alloc_adv-#-FSC.pif$',
OUTPUT_BLOCK_NAME          => 'Dyn_alloc_adv',
PRODUCE_PIF                => 0,
OUTPUT_FORMAT              => 'LIF_Writer',
},

#{
#RULE_TYPE => 'FILE_SPLIT',
#RULE_DESC => "Split carrier_stats based on carrierid",
#INPUT_FILE_DESCRIPTION => ['carrier_stats-#-.+-#-J.pif'],
#COUNTERS_USED_TO_SPLIT_FILE => {
#	#'carrierid' => '(.+)',
#	'nodeid' => '(.+)',
#	'day' => '(.+)',
#	'start' => '(.+)',
#	'end' => '(.+)',
#	},
#SPLIT_COUNTERS_ORDER => [ qw(day start end nodeid) ],
#PRODUCE_PIF => 0,
#PRODUCE_LIF => "True",
##OUTPUT_BLOCK_NAME => 'FS',
#REDUNDANT_DATA_COUNTERS => [],
#},

{
'RULE_TYPE' => 'PIF_2_LIF',
'RULE_NAME' => "Ericsson 6.0 PIF to LIF",
'INPUT_FILE_DESCRIPTION' => [
'^axcdr.+-#-FS.pif$',
'^carrier_stats2.+-#-FS.pif$',
'^carrier_stats3.+-#-FS.pif$',
#'^carrier_stats4.+-#-FS.pif$',
'^bss.+-#-FS.pif$',
'^cbl.+-#-FS.pif$',
'^dproc.+-#-FS.pif$',
'^dynetgp.+-#-FS.pif$',
'^gbl.+-#-FS.pif$',
'^gproc.+-#-FS.pif$',
'^gsl.+-#-FS.pif$',
'^lmtl.+-#-FS.pif$',
'^mtl.+-#-FS.pif$',
'^nbr.+-#-FS.pif$',
'^oml.+-#-FS.pif$',
'^pcu.+-#-FS.pif$',
'^rsl.+-#-FS.pif$',
'^xbl.+-#-FS.pif$',
],
'PRODUCE_PIF' => 0,
'PRODUCE_LIF' => "True",
},

);


#-------------------------------------------------------------------------------

sub postparser_config {
	return \@rules;
}

1;
